@@ -1,8 +1,6 @@
 package App::cpm::Worker;
 use strict;
 use warnings;
-use utf8;
-our $VERSION = '0.972';
 
 use App::cpm::Worker::Installer;
 use App::cpm::Worker::Resolver;
